@@ -23,13 +23,16 @@ __all__ = (
     "ApplicationStatusType",
     "InputStartingPositionType",
     "RecordFormatTypeType",
+    "KinesisAnalyticsServiceName",
     "ServiceName",
+    "ResourceServiceName",
 )
 
 
 ApplicationStatusType = Literal["DELETING", "READY", "RUNNING", "STARTING", "STOPPING", "UPDATING"]
 InputStartingPositionType = Literal["LAST_STOPPED_POINT", "NOW", "TRIM_HORIZON"]
 RecordFormatTypeType = Literal["CSV", "JSON"]
+KinesisAnalyticsServiceName = Literal["kinesisanalytics"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -61,6 +64,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -183,6 +187,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -331,3 +336,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
