@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
+from typing_extensions import NotRequired
+
 from .literals import ApplicationStatusType, InputStartingPositionType, RecordFormatTypeType
 
 if sys.version_info >= (3, 9):
@@ -151,36 +153,27 @@ AddApplicationReferenceDataSourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredApplicationDetailTypeDef = TypedDict(
-    "_RequiredApplicationDetailTypeDef",
+ApplicationDetailTypeDef = TypedDict(
+    "ApplicationDetailTypeDef",
     {
         "ApplicationName": str,
         "ApplicationARN": str,
         "ApplicationStatus": ApplicationStatusType,
         "ApplicationVersionId": int,
+        "ApplicationDescription": NotRequired[str],
+        "CreateTimestamp": NotRequired[datetime],
+        "LastUpdateTimestamp": NotRequired[datetime],
+        "InputDescriptions": NotRequired[List["InputDescriptionTypeDef"]],
+        "OutputDescriptions": NotRequired[List["OutputDescriptionTypeDef"]],
+        "ReferenceDataSourceDescriptions": NotRequired[
+            List["ReferenceDataSourceDescriptionTypeDef"]
+        ],
+        "CloudWatchLoggingOptionDescriptions": NotRequired[
+            List["CloudWatchLoggingOptionDescriptionTypeDef"]
+        ],
+        "ApplicationCode": NotRequired[str],
     },
 )
-_OptionalApplicationDetailTypeDef = TypedDict(
-    "_OptionalApplicationDetailTypeDef",
-    {
-        "ApplicationDescription": str,
-        "CreateTimestamp": datetime,
-        "LastUpdateTimestamp": datetime,
-        "InputDescriptions": List["InputDescriptionTypeDef"],
-        "OutputDescriptions": List["OutputDescriptionTypeDef"],
-        "ReferenceDataSourceDescriptions": List["ReferenceDataSourceDescriptionTypeDef"],
-        "CloudWatchLoggingOptionDescriptions": List["CloudWatchLoggingOptionDescriptionTypeDef"],
-        "ApplicationCode": str,
-    },
-    total=False,
-)
-
-
-class ApplicationDetailTypeDef(
-    _RequiredApplicationDetailTypeDef, _OptionalApplicationDetailTypeDef
-):
-    pass
-
 
 ApplicationSummaryTypeDef = TypedDict(
     "ApplicationSummaryTypeDef",
@@ -194,13 +187,14 @@ ApplicationSummaryTypeDef = TypedDict(
 ApplicationUpdateTypeDef = TypedDict(
     "ApplicationUpdateTypeDef",
     {
-        "InputUpdates": Sequence["InputUpdateTypeDef"],
-        "ApplicationCodeUpdate": str,
-        "OutputUpdates": Sequence["OutputUpdateTypeDef"],
-        "ReferenceDataSourceUpdates": Sequence["ReferenceDataSourceUpdateTypeDef"],
-        "CloudWatchLoggingOptionUpdates": Sequence["CloudWatchLoggingOptionUpdateTypeDef"],
+        "InputUpdates": NotRequired[Sequence["InputUpdateTypeDef"]],
+        "ApplicationCodeUpdate": NotRequired[str],
+        "OutputUpdates": NotRequired[Sequence["OutputUpdateTypeDef"]],
+        "ReferenceDataSourceUpdates": NotRequired[Sequence["ReferenceDataSourceUpdateTypeDef"]],
+        "CloudWatchLoggingOptionUpdates": NotRequired[
+            Sequence["CloudWatchLoggingOptionUpdateTypeDef"]
+        ],
     },
-    total=False,
 )
 
 CSVMappingParametersTypeDef = TypedDict(
@@ -211,28 +205,14 @@ CSVMappingParametersTypeDef = TypedDict(
     },
 )
 
-_RequiredCloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
-    "_RequiredCloudWatchLoggingOptionDescriptionTypeDef",
+CloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
+    "CloudWatchLoggingOptionDescriptionTypeDef",
     {
         "LogStreamARN": str,
         "RoleARN": str,
+        "CloudWatchLoggingOptionId": NotRequired[str],
     },
 )
-_OptionalCloudWatchLoggingOptionDescriptionTypeDef = TypedDict(
-    "_OptionalCloudWatchLoggingOptionDescriptionTypeDef",
-    {
-        "CloudWatchLoggingOptionId": str,
-    },
-    total=False,
-)
-
-
-class CloudWatchLoggingOptionDescriptionTypeDef(
-    _RequiredCloudWatchLoggingOptionDescriptionTypeDef,
-    _OptionalCloudWatchLoggingOptionDescriptionTypeDef,
-):
-    pass
-
 
 CloudWatchLoggingOptionTypeDef = TypedDict(
     "CloudWatchLoggingOptionTypeDef",
@@ -242,53 +222,27 @@ CloudWatchLoggingOptionTypeDef = TypedDict(
     },
 )
 
-_RequiredCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
-    "_RequiredCloudWatchLoggingOptionUpdateTypeDef",
+CloudWatchLoggingOptionUpdateTypeDef = TypedDict(
+    "CloudWatchLoggingOptionUpdateTypeDef",
     {
         "CloudWatchLoggingOptionId": str,
+        "LogStreamARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
 )
-_OptionalCloudWatchLoggingOptionUpdateTypeDef = TypedDict(
-    "_OptionalCloudWatchLoggingOptionUpdateTypeDef",
-    {
-        "LogStreamARNUpdate": str,
-        "RoleARNUpdate": str,
-    },
-    total=False,
-)
 
-
-class CloudWatchLoggingOptionUpdateTypeDef(
-    _RequiredCloudWatchLoggingOptionUpdateTypeDef, _OptionalCloudWatchLoggingOptionUpdateTypeDef
-):
-    pass
-
-
-_RequiredCreateApplicationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateApplicationRequestRequestTypeDef",
+CreateApplicationRequestRequestTypeDef = TypedDict(
+    "CreateApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
+        "ApplicationDescription": NotRequired[str],
+        "Inputs": NotRequired[Sequence["InputTypeDef"]],
+        "Outputs": NotRequired[Sequence["OutputTypeDef"]],
+        "CloudWatchLoggingOptions": NotRequired[Sequence["CloudWatchLoggingOptionTypeDef"]],
+        "ApplicationCode": NotRequired[str],
+        "Tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
-_OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateApplicationRequestRequestTypeDef",
-    {
-        "ApplicationDescription": str,
-        "Inputs": Sequence["InputTypeDef"],
-        "Outputs": Sequence["OutputTypeDef"],
-        "CloudWatchLoggingOptions": Sequence["CloudWatchLoggingOptionTypeDef"],
-        "ApplicationCode": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateApplicationRequestRequestTypeDef(
-    _RequiredCreateApplicationRequestRequestTypeDef, _OptionalCreateApplicationRequestRequestTypeDef
-):
-    pass
-
 
 CreateApplicationResponseTypeDef = TypedDict(
     "CreateApplicationResponseTypeDef",
@@ -367,13 +321,14 @@ DestinationSchemaTypeDef = TypedDict(
 DiscoverInputSchemaRequestRequestTypeDef = TypedDict(
     "DiscoverInputSchemaRequestRequestTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
-        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
-        "S3Configuration": "S3ConfigurationTypeDef",
-        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
+        "InputStartingPositionConfiguration": NotRequired[
+            "InputStartingPositionConfigurationTypeDef"
+        ],
+        "S3Configuration": NotRequired["S3ConfigurationTypeDef"],
+        "InputProcessingConfiguration": NotRequired["InputProcessingConfigurationTypeDef"],
     },
-    total=False,
 )
 
 DiscoverInputSchemaResponseTypeDef = TypedDict(
@@ -398,26 +353,28 @@ InputConfigurationTypeDef = TypedDict(
 InputDescriptionTypeDef = TypedDict(
     "InputDescriptionTypeDef",
     {
-        "InputId": str,
-        "NamePrefix": str,
-        "InAppStreamNames": List[str],
-        "InputProcessingConfigurationDescription": "InputProcessingConfigurationDescriptionTypeDef",
-        "KinesisStreamsInputDescription": "KinesisStreamsInputDescriptionTypeDef",
-        "KinesisFirehoseInputDescription": "KinesisFirehoseInputDescriptionTypeDef",
-        "InputSchema": "SourceSchemaTypeDef",
-        "InputParallelism": "InputParallelismTypeDef",
-        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+        "InputId": NotRequired[str],
+        "NamePrefix": NotRequired[str],
+        "InAppStreamNames": NotRequired[List[str]],
+        "InputProcessingConfigurationDescription": NotRequired[
+            "InputProcessingConfigurationDescriptionTypeDef"
+        ],
+        "KinesisStreamsInputDescription": NotRequired["KinesisStreamsInputDescriptionTypeDef"],
+        "KinesisFirehoseInputDescription": NotRequired["KinesisFirehoseInputDescriptionTypeDef"],
+        "InputSchema": NotRequired["SourceSchemaTypeDef"],
+        "InputParallelism": NotRequired["InputParallelismTypeDef"],
+        "InputStartingPositionConfiguration": NotRequired[
+            "InputStartingPositionConfigurationTypeDef"
+        ],
     },
-    total=False,
 )
 
 InputLambdaProcessorDescriptionTypeDef = TypedDict(
     "InputLambdaProcessorDescriptionTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
     },
-    total=False,
 )
 
 InputLambdaProcessorTypeDef = TypedDict(
@@ -431,34 +388,30 @@ InputLambdaProcessorTypeDef = TypedDict(
 InputLambdaProcessorUpdateTypeDef = TypedDict(
     "InputLambdaProcessorUpdateTypeDef",
     {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
+        "ResourceARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
 InputParallelismTypeDef = TypedDict(
     "InputParallelismTypeDef",
     {
-        "Count": int,
+        "Count": NotRequired[int],
     },
-    total=False,
 )
 
 InputParallelismUpdateTypeDef = TypedDict(
     "InputParallelismUpdateTypeDef",
     {
-        "CountUpdate": int,
+        "CountUpdate": NotRequired[int],
     },
-    total=False,
 )
 
 InputProcessingConfigurationDescriptionTypeDef = TypedDict(
     "InputProcessingConfigurationDescriptionTypeDef",
     {
-        "InputLambdaProcessorDescription": "InputLambdaProcessorDescriptionTypeDef",
+        "InputLambdaProcessorDescription": NotRequired["InputLambdaProcessorDescriptionTypeDef"],
     },
-    total=False,
 )
 
 InputProcessingConfigurationTypeDef = TypedDict(
@@ -478,67 +431,45 @@ InputProcessingConfigurationUpdateTypeDef = TypedDict(
 InputSchemaUpdateTypeDef = TypedDict(
     "InputSchemaUpdateTypeDef",
     {
-        "RecordFormatUpdate": "RecordFormatTypeDef",
-        "RecordEncodingUpdate": str,
-        "RecordColumnUpdates": Sequence["RecordColumnTypeDef"],
+        "RecordFormatUpdate": NotRequired["RecordFormatTypeDef"],
+        "RecordEncodingUpdate": NotRequired[str],
+        "RecordColumnUpdates": NotRequired[Sequence["RecordColumnTypeDef"]],
     },
-    total=False,
 )
 
 InputStartingPositionConfigurationTypeDef = TypedDict(
     "InputStartingPositionConfigurationTypeDef",
     {
-        "InputStartingPosition": InputStartingPositionType,
+        "InputStartingPosition": NotRequired[InputStartingPositionType],
     },
-    total=False,
 )
 
-_RequiredInputTypeDef = TypedDict(
-    "_RequiredInputTypeDef",
+InputTypeDef = TypedDict(
+    "InputTypeDef",
     {
         "NamePrefix": str,
         "InputSchema": "SourceSchemaTypeDef",
+        "InputProcessingConfiguration": NotRequired["InputProcessingConfigurationTypeDef"],
+        "KinesisStreamsInput": NotRequired["KinesisStreamsInputTypeDef"],
+        "KinesisFirehoseInput": NotRequired["KinesisFirehoseInputTypeDef"],
+        "InputParallelism": NotRequired["InputParallelismTypeDef"],
     },
 )
-_OptionalInputTypeDef = TypedDict(
-    "_OptionalInputTypeDef",
-    {
-        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
-        "KinesisStreamsInput": "KinesisStreamsInputTypeDef",
-        "KinesisFirehoseInput": "KinesisFirehoseInputTypeDef",
-        "InputParallelism": "InputParallelismTypeDef",
-    },
-    total=False,
-)
 
-
-class InputTypeDef(_RequiredInputTypeDef, _OptionalInputTypeDef):
-    pass
-
-
-_RequiredInputUpdateTypeDef = TypedDict(
-    "_RequiredInputUpdateTypeDef",
+InputUpdateTypeDef = TypedDict(
+    "InputUpdateTypeDef",
     {
         "InputId": str,
+        "NamePrefixUpdate": NotRequired[str],
+        "InputProcessingConfigurationUpdate": NotRequired[
+            "InputProcessingConfigurationUpdateTypeDef"
+        ],
+        "KinesisStreamsInputUpdate": NotRequired["KinesisStreamsInputUpdateTypeDef"],
+        "KinesisFirehoseInputUpdate": NotRequired["KinesisFirehoseInputUpdateTypeDef"],
+        "InputSchemaUpdate": NotRequired["InputSchemaUpdateTypeDef"],
+        "InputParallelismUpdate": NotRequired["InputParallelismUpdateTypeDef"],
     },
 )
-_OptionalInputUpdateTypeDef = TypedDict(
-    "_OptionalInputUpdateTypeDef",
-    {
-        "NamePrefixUpdate": str,
-        "InputProcessingConfigurationUpdate": "InputProcessingConfigurationUpdateTypeDef",
-        "KinesisStreamsInputUpdate": "KinesisStreamsInputUpdateTypeDef",
-        "KinesisFirehoseInputUpdate": "KinesisFirehoseInputUpdateTypeDef",
-        "InputSchemaUpdate": "InputSchemaUpdateTypeDef",
-        "InputParallelismUpdate": "InputParallelismUpdateTypeDef",
-    },
-    total=False,
-)
-
-
-class InputUpdateTypeDef(_RequiredInputUpdateTypeDef, _OptionalInputUpdateTypeDef):
-    pass
-
 
 JSONMappingParametersTypeDef = TypedDict(
     "JSONMappingParametersTypeDef",
@@ -550,10 +481,9 @@ JSONMappingParametersTypeDef = TypedDict(
 KinesisFirehoseInputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseInputDescriptionTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisFirehoseInputTypeDef = TypedDict(
@@ -567,19 +497,17 @@ KinesisFirehoseInputTypeDef = TypedDict(
 KinesisFirehoseInputUpdateTypeDef = TypedDict(
     "KinesisFirehoseInputUpdateTypeDef",
     {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
+        "ResourceARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisFirehoseOutputDescriptionTypeDef = TypedDict(
     "KinesisFirehoseOutputDescriptionTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisFirehoseOutputTypeDef = TypedDict(
@@ -593,19 +521,17 @@ KinesisFirehoseOutputTypeDef = TypedDict(
 KinesisFirehoseOutputUpdateTypeDef = TypedDict(
     "KinesisFirehoseOutputUpdateTypeDef",
     {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
+        "ResourceARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisStreamsInputDescriptionTypeDef = TypedDict(
     "KinesisStreamsInputDescriptionTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisStreamsInputTypeDef = TypedDict(
@@ -619,19 +545,17 @@ KinesisStreamsInputTypeDef = TypedDict(
 KinesisStreamsInputUpdateTypeDef = TypedDict(
     "KinesisStreamsInputUpdateTypeDef",
     {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
+        "ResourceARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisStreamsOutputDescriptionTypeDef = TypedDict(
     "KinesisStreamsOutputDescriptionTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
     },
-    total=False,
 )
 
 KinesisStreamsOutputTypeDef = TypedDict(
@@ -645,19 +569,17 @@ KinesisStreamsOutputTypeDef = TypedDict(
 KinesisStreamsOutputUpdateTypeDef = TypedDict(
     "KinesisStreamsOutputUpdateTypeDef",
     {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
+        "ResourceARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
 LambdaOutputDescriptionTypeDef = TypedDict(
     "LambdaOutputDescriptionTypeDef",
     {
-        "ResourceARN": str,
-        "RoleARN": str,
+        "ResourceARN": NotRequired[str],
+        "RoleARN": NotRequired[str],
     },
-    total=False,
 )
 
 LambdaOutputTypeDef = TypedDict(
@@ -671,19 +593,17 @@ LambdaOutputTypeDef = TypedDict(
 LambdaOutputUpdateTypeDef = TypedDict(
     "LambdaOutputUpdateTypeDef",
     {
-        "ResourceARNUpdate": str,
-        "RoleARNUpdate": str,
+        "ResourceARNUpdate": NotRequired[str],
+        "RoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
 ListApplicationsRequestRequestTypeDef = TypedDict(
     "ListApplicationsRequestRequestTypeDef",
     {
-        "Limit": int,
-        "ExclusiveStartApplicationName": str,
+        "Limit": NotRequired[int],
+        "ExclusiveStartApplicationName": NotRequired[str],
     },
-    total=False,
 )
 
 ListApplicationsResponseTypeDef = TypedDict(
@@ -713,176 +633,91 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 MappingParametersTypeDef = TypedDict(
     "MappingParametersTypeDef",
     {
-        "JSONMappingParameters": "JSONMappingParametersTypeDef",
-        "CSVMappingParameters": "CSVMappingParametersTypeDef",
+        "JSONMappingParameters": NotRequired["JSONMappingParametersTypeDef"],
+        "CSVMappingParameters": NotRequired["CSVMappingParametersTypeDef"],
     },
-    total=False,
 )
 
 OutputDescriptionTypeDef = TypedDict(
     "OutputDescriptionTypeDef",
     {
-        "OutputId": str,
-        "Name": str,
-        "KinesisStreamsOutputDescription": "KinesisStreamsOutputDescriptionTypeDef",
-        "KinesisFirehoseOutputDescription": "KinesisFirehoseOutputDescriptionTypeDef",
-        "LambdaOutputDescription": "LambdaOutputDescriptionTypeDef",
-        "DestinationSchema": "DestinationSchemaTypeDef",
+        "OutputId": NotRequired[str],
+        "Name": NotRequired[str],
+        "KinesisStreamsOutputDescription": NotRequired["KinesisStreamsOutputDescriptionTypeDef"],
+        "KinesisFirehoseOutputDescription": NotRequired["KinesisFirehoseOutputDescriptionTypeDef"],
+        "LambdaOutputDescription": NotRequired["LambdaOutputDescriptionTypeDef"],
+        "DestinationSchema": NotRequired["DestinationSchemaTypeDef"],
     },
-    total=False,
 )
 
-_RequiredOutputTypeDef = TypedDict(
-    "_RequiredOutputTypeDef",
+OutputTypeDef = TypedDict(
+    "OutputTypeDef",
     {
         "Name": str,
         "DestinationSchema": "DestinationSchemaTypeDef",
+        "KinesisStreamsOutput": NotRequired["KinesisStreamsOutputTypeDef"],
+        "KinesisFirehoseOutput": NotRequired["KinesisFirehoseOutputTypeDef"],
+        "LambdaOutput": NotRequired["LambdaOutputTypeDef"],
     },
 )
-_OptionalOutputTypeDef = TypedDict(
-    "_OptionalOutputTypeDef",
-    {
-        "KinesisStreamsOutput": "KinesisStreamsOutputTypeDef",
-        "KinesisFirehoseOutput": "KinesisFirehoseOutputTypeDef",
-        "LambdaOutput": "LambdaOutputTypeDef",
-    },
-    total=False,
-)
 
-
-class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
-    pass
-
-
-_RequiredOutputUpdateTypeDef = TypedDict(
-    "_RequiredOutputUpdateTypeDef",
+OutputUpdateTypeDef = TypedDict(
+    "OutputUpdateTypeDef",
     {
         "OutputId": str,
+        "NameUpdate": NotRequired[str],
+        "KinesisStreamsOutputUpdate": NotRequired["KinesisStreamsOutputUpdateTypeDef"],
+        "KinesisFirehoseOutputUpdate": NotRequired["KinesisFirehoseOutputUpdateTypeDef"],
+        "LambdaOutputUpdate": NotRequired["LambdaOutputUpdateTypeDef"],
+        "DestinationSchemaUpdate": NotRequired["DestinationSchemaTypeDef"],
     },
 )
-_OptionalOutputUpdateTypeDef = TypedDict(
-    "_OptionalOutputUpdateTypeDef",
-    {
-        "NameUpdate": str,
-        "KinesisStreamsOutputUpdate": "KinesisStreamsOutputUpdateTypeDef",
-        "KinesisFirehoseOutputUpdate": "KinesisFirehoseOutputUpdateTypeDef",
-        "LambdaOutputUpdate": "LambdaOutputUpdateTypeDef",
-        "DestinationSchemaUpdate": "DestinationSchemaTypeDef",
-    },
-    total=False,
-)
 
-
-class OutputUpdateTypeDef(_RequiredOutputUpdateTypeDef, _OptionalOutputUpdateTypeDef):
-    pass
-
-
-_RequiredRecordColumnTypeDef = TypedDict(
-    "_RequiredRecordColumnTypeDef",
+RecordColumnTypeDef = TypedDict(
+    "RecordColumnTypeDef",
     {
         "Name": str,
         "SqlType": str,
+        "Mapping": NotRequired[str],
     },
 )
-_OptionalRecordColumnTypeDef = TypedDict(
-    "_OptionalRecordColumnTypeDef",
-    {
-        "Mapping": str,
-    },
-    total=False,
-)
 
-
-class RecordColumnTypeDef(_RequiredRecordColumnTypeDef, _OptionalRecordColumnTypeDef):
-    pass
-
-
-_RequiredRecordFormatTypeDef = TypedDict(
-    "_RequiredRecordFormatTypeDef",
+RecordFormatTypeDef = TypedDict(
+    "RecordFormatTypeDef",
     {
         "RecordFormatType": RecordFormatTypeType,
+        "MappingParameters": NotRequired["MappingParametersTypeDef"],
     },
 )
-_OptionalRecordFormatTypeDef = TypedDict(
-    "_OptionalRecordFormatTypeDef",
-    {
-        "MappingParameters": "MappingParametersTypeDef",
-    },
-    total=False,
-)
 
-
-class RecordFormatTypeDef(_RequiredRecordFormatTypeDef, _OptionalRecordFormatTypeDef):
-    pass
-
-
-_RequiredReferenceDataSourceDescriptionTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceDescriptionTypeDef",
+ReferenceDataSourceDescriptionTypeDef = TypedDict(
+    "ReferenceDataSourceDescriptionTypeDef",
     {
         "ReferenceId": str,
         "TableName": str,
         "S3ReferenceDataSourceDescription": "S3ReferenceDataSourceDescriptionTypeDef",
+        "ReferenceSchema": NotRequired["SourceSchemaTypeDef"],
     },
 )
-_OptionalReferenceDataSourceDescriptionTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceDescriptionTypeDef",
-    {
-        "ReferenceSchema": "SourceSchemaTypeDef",
-    },
-    total=False,
-)
 
-
-class ReferenceDataSourceDescriptionTypeDef(
-    _RequiredReferenceDataSourceDescriptionTypeDef, _OptionalReferenceDataSourceDescriptionTypeDef
-):
-    pass
-
-
-_RequiredReferenceDataSourceTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceTypeDef",
+ReferenceDataSourceTypeDef = TypedDict(
+    "ReferenceDataSourceTypeDef",
     {
         "TableName": str,
         "ReferenceSchema": "SourceSchemaTypeDef",
+        "S3ReferenceDataSource": NotRequired["S3ReferenceDataSourceTypeDef"],
     },
 )
-_OptionalReferenceDataSourceTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceTypeDef",
-    {
-        "S3ReferenceDataSource": "S3ReferenceDataSourceTypeDef",
-    },
-    total=False,
-)
 
-
-class ReferenceDataSourceTypeDef(
-    _RequiredReferenceDataSourceTypeDef, _OptionalReferenceDataSourceTypeDef
-):
-    pass
-
-
-_RequiredReferenceDataSourceUpdateTypeDef = TypedDict(
-    "_RequiredReferenceDataSourceUpdateTypeDef",
+ReferenceDataSourceUpdateTypeDef = TypedDict(
+    "ReferenceDataSourceUpdateTypeDef",
     {
         "ReferenceId": str,
+        "TableNameUpdate": NotRequired[str],
+        "S3ReferenceDataSourceUpdate": NotRequired["S3ReferenceDataSourceUpdateTypeDef"],
+        "ReferenceSchemaUpdate": NotRequired["SourceSchemaTypeDef"],
     },
 )
-_OptionalReferenceDataSourceUpdateTypeDef = TypedDict(
-    "_OptionalReferenceDataSourceUpdateTypeDef",
-    {
-        "TableNameUpdate": str,
-        "S3ReferenceDataSourceUpdate": "S3ReferenceDataSourceUpdateTypeDef",
-        "ReferenceSchemaUpdate": "SourceSchemaTypeDef",
-    },
-    total=False,
-)
-
-
-class ReferenceDataSourceUpdateTypeDef(
-    _RequiredReferenceDataSourceUpdateTypeDef, _OptionalReferenceDataSourceUpdateTypeDef
-):
-    pass
-
 
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
@@ -925,32 +760,20 @@ S3ReferenceDataSourceTypeDef = TypedDict(
 S3ReferenceDataSourceUpdateTypeDef = TypedDict(
     "S3ReferenceDataSourceUpdateTypeDef",
     {
-        "BucketARNUpdate": str,
-        "FileKeyUpdate": str,
-        "ReferenceRoleARNUpdate": str,
+        "BucketARNUpdate": NotRequired[str],
+        "FileKeyUpdate": NotRequired[str],
+        "ReferenceRoleARNUpdate": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredSourceSchemaTypeDef = TypedDict(
-    "_RequiredSourceSchemaTypeDef",
+SourceSchemaTypeDef = TypedDict(
+    "SourceSchemaTypeDef",
     {
         "RecordFormat": "RecordFormatTypeDef",
         "RecordColumns": Sequence["RecordColumnTypeDef"],
+        "RecordEncoding": NotRequired[str],
     },
 )
-_OptionalSourceSchemaTypeDef = TypedDict(
-    "_OptionalSourceSchemaTypeDef",
-    {
-        "RecordEncoding": str,
-    },
-    total=False,
-)
-
-
-class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTypeDef):
-    pass
-
 
 StartApplicationRequestRequestTypeDef = TypedDict(
     "StartApplicationRequestRequestTypeDef",
@@ -975,24 +798,13 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredTagTypeDef = TypedDict(
-    "_RequiredTagTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
         "Key": str,
+        "Value": NotRequired[str],
     },
 )
-_OptionalTagTypeDef = TypedDict(
-    "_OptionalTagTypeDef",
-    {
-        "Value": str,
-    },
-    total=False,
-)
-
-
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
-    pass
-
 
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
